---
title: '[공지] 결제사 정산 업데이트 오류 안내 (조치완료)'
category: 공지사항
seo:
  title: '[공지] 결제사 정산 업데이트 오류 안내'
  description: "안녕하세요, 포트원\_고객지원팀입니다.\n현재 당사의 결제사\_정산 서비스에서\_데이터 정확도를 위한 보강 작업을 진행하였으나,\n정산 데이터가 중복\_집계되는\_이슈가 발생하여 공지드립니다.\n"
tags:
  - 공지사항
pgCompanies:
  - null
datetime: 2024-04-26T09:53:36.865Z
---

안녕하세요. 포트원 고객지원팀입니다.

현재 당사의 결제사 정산 서비스에서 데이터 정확도를 위한 보강 작업을 진행하였으나,

정산 데이터가 중복 집계되는 이슈가 발생하여 공지드립니다.

---

1. 이슈 내용 : 결제사 정산 4/1-4/12까지의 데이터가 중복 집계되는 이슈 발생
2. 작업 일정 : 4/26-4/28 내부 작업으로 인하여 4월 정산 데이터 조회 불가 → 4/29 정상 제공 예정

이용에 불편을 드려 죄송합니다.
